@@ -52,17 +52,26 @@ FREQ_LOW = 10
 FREQ_MEDIUM = 20
 FREQ_HIGH = 30
 
+###############################################################################
+# Default Fantasy Multipliers
+
 FANTASY = {
     'kills': 0.3,
     'deaths': -0.3,
-    'assists': 0.15,
+    'assists': 0,
     'last_hits': 0.003,
     'gold_per_min': 0.002,
     'xp_per_min': 0,
     'tower_kills': 1,
+    'tower_damage': 0,
+    'hero_damage': 0,
+    'courier_kills': 0,
+    'observer_kills': 0,
+    'sentry_kills': 0,
     'roshan_kills': 1,
     'teamfight': 3,
-    'wards_placed': 0.5,
+    'observer_placed': 0.5,
+    'sentry_placed': 0,
     'camps_stacked': 0.5,
     'runes_grabbed': 0.25,
     'first_blood': 4,
@@ -73,6 +82,22 @@ FANTASY = {
     'deaths_base': 3,
 }
 
+# TODO: potential metrics
+# - kill_streaks
+# - multi_kills
+
+FANTASY_RECOMMENDED = {
+    'kills': 0.15,
+    'assists': 0.05,
+    'tower_kills': 0.5,
+    'tower_damage': 0.0002,
+    'hero_damage': 0.0001,
+    'courier_kills': 0.2,
+    'observer_kills': 0.5,
+    'roshan_kills': 1.5,
+    'first_blood': 2
+}
+
 ###############################################################################
 
 
@@ -556,9 +581,33 @@ class OpenDota:
         fantasy_points = []
 
         for player in match['players']:
+            player_slot = player['player_slot']
+            player_side = 'radiant' if player['player_slot'] < 5 else 'dire'
+            player_team = match[f'{player_side}_team']
+            player_result = (
+                'win'
+                if match['radiant_win'] == (player_side == 'radiant')
+                else 'loss'
+            )
+
             player_fantasy = {
-                'player_slot': player['player_slot'],
-                'account_id': player['account_id'],
+                'match': {
+                    'match_id': match['match_id'],
+                    'series_id': match['series_id'],
+                    'series_type': match['series_type']
+                },
+                'player': {
+                    'account_id': player['account_id'],
+                    'slot': player_slot,
+                    'side': player_side,
+                    'name': player['name'],
+                    'result': player_result
+                },
+                'team': {
+                    'team_id': player_team['team_id'],
+                    'name': player_team['name'],
+                    'tag': player_team['tag']
+                },
                 'fantasy': {
                     'kills': {
                         'value': player['kills']
@@ -581,15 +630,33 @@ class OpenDota:
                     'tower_kills': {
                         'value': player['tower_kills']
                     },
+                    'tower_damage': {
+                        'value': player['tower_damage']
+                    },
+                    'hero_damage': {
+                        'value': player['hero_damage']
+                    },
+                    'courier_kills': {
+                        'value': player['courier_kills']
+                    },
+                    'observer_kills': {
+                        'value': player['observer_kills']
+                    },
+                    'sentry_kills': {
+                        'value': player['sentry_kills']
+                    },
                     'roshan_kills': {
                         'value': player['roshan_kills']
                     },
                     'teamfight': {
                         'value': player['teamfight_participation']
                     },
-                    'wards_placed': {
+                    'observer_placed': {
                         'value': player['obs_placed']
                     },
+                    'sentry_placed': {
+                        'value': player['sen_placed']
+                    },
                     'camps_stacked': {
                         'value': player['camps_stacked']
                     },
